summaryrefslogtreecommitdiff
path: root/src/configuration.h
diff options
context:
space:
mode:
authorYohann Ferreira <yohann_dot_ferreira_at_orange_dot_efer>2010-07-11 20:05:44 +0200
committerYohann Ferreira <yohann_dot_ferreira_at_orange_dot_efer>2010-07-11 20:05:44 +0200
commitabde0f51b3062c158fb52e9dfff23d21d3be03d1 (patch)
tree4af561ea9e8cd3f7f981cce9817cf57f3e353787 /src/configuration.h
parent93e1a2a9e5f379945a6efb24598319b605be1dfa (diff)
downloadmana-client-abde0f51b3062c158fb52e9dfff23d21d3be03d1.tar.gz
mana-client-abde0f51b3062c158fb52e9dfff23d21d3be03d1.tar.bz2
mana-client-abde0f51b3062c158fb52e9dfff23d21d3be03d1.tar.xz
mana-client-abde0f51b3062c158fb52e9dfff23d21d3be03d1.zip
Made the different hard-coded paths and files be now taken from the
data/paths.xml configuration file. Also added default gui theme path in branding and default wallpaper path and file searched respectively in the branding and paths.xml files. Hard-coded values are still used as fallbacks. Resolves: Manasource Mantis #148. Reviewed-by: jaxad0127.
Diffstat (limited to 'src/configuration.h')
-rw-r--r--src/configuration.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/configuration.h b/src/configuration.h
index a0c896a5..908d13a4 100644
--- a/src/configuration.h
+++ b/src/configuration.h
@@ -197,9 +197,10 @@ class Configuration : public ConfigurationObject
/**
* Reads config file and parse all options into memory.
*
* \param filename path to config file
*/
- void init(const std::string &filename);
+ void init(const std::string &filename, bool useResManager = false);
/**
* Writes the current settings back to the config file.
@@ -244,10 +245,11 @@ class Configuration : public ConfigurationObject
typedef ListenerMap::iterator ListenerMapIterator;
ListenerMap mListenerMap;
- std::string mConfigPath; /**< Location of config file */
+ std::string mConfigPath; /**< Location of config file */
};
extern Configuration branding;
extern Configuration config;
+extern Configuration paths;
#endif
@@ -197,9 +197,10 @@ class Configuration : public ConfigurationObject
* Reads config file and parse all options into memory.
*
- * \param filename path to config file
+ * @param filename path to config file
+ * @param useResManager Make use of the resource manager.
*/